@@ -11,7 +11,7 @@ PZ
 T <- 100
 init_parameters <- list(P = 2, Z = 2, mu = 0.5, sigma = 0.3)
 # First let's generate a dataset from the model
-synthetic_dataset <- bi_generate_dataset(end_time=T, model=PZ,
+synthetic_dataset <- bi_generate_dataset(model=PZ, end_time=T,
                                          init=init_parameters)
 # Settings
 bi_object <- libbi(model=PZ)
